#
# spec file for package twind
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           twind
Version:        1.1.0
Release:        4.1
Summary:        Match and remove all of the blocks before time runs out
License:        GPL-2.0
Group:          Amusements/Games/Arcade/LogicGame
Url:            http://twind.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.sh
Source2:        %{name}.desktop
# PATCH-FIX-OPENSUSE - twind-1.1.0.twind.c.patch -- Correct bad code
Patch0:         %{name}-1.1.0.twind.c.patch
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
%endif
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(sdl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The object of the game is to remove all of the blocks from the screen
before the time runs out. Two blocks are removed at a time,
and must be of the same color. After completing a level,
you will be rewarded with a bonus point for every tick left on the clock.
For each level thereafter, the time to complete the the level will be shorter.

Shortcut Keys Used During the Game

 b - change the block set
 c - change the corner style of the blocks
 f, F4 - toggle between full screen/window mode (can be used anywhere)
 h, F1 - display the help screen
 m - turn background music on/off (can be used anywhere)
 n, F2 - start a new game (highscores won't be saved ending a game this way)
 p, Pause, F3 - pause/unpause the game
 q, Esc - quit the game
 s - turn sound effects on/off (can be used anywhere)
 0 - 9 - toggle the L & R colors on Insane mode (can be used anywhere)

%prep
%autosetup -p0

# SED-FIX-OPENSUSE -- Correct Path and Highscore
sed -i -e 's|chown |true |;
           s|/usr/local/bin|${DESTDIR}%{_libexecdir}/%{name}|;
           s|/usr/local/share/games/%{name}|${DESTDIR}%{_libexecdir}/%{name}|;
           s|HIGH_SCORE_PREFIX =|#HIGH_SCORE_PREFIX =|;
           s|mkdir -p $(HIGH_SCORE_PREFIX)||' Makefile

%build
make %{?_smp_mflags} CFLAGS="%{optflags} -fgnu89-inline"

%install
mkdir -p %{buildroot}%{_bindir}
%make_install

# install wrapper
install -Dm 0755 %{S:1} %{buildroot}%{_bindir}/%{name}

# install icon
install -Dm 0644 graphics/%{name}.png %{buildroot}/%{_datadir}/icons/hicolor/32x32/apps/%{name}.png

# install Desktop file
install -Dm 0644 %{S:2} %{buildroot}%{_datadir}/applications/%{name}.desktop

%if 0%{?suse_version}
    %suse_update_desktop_file %{name}
    %fdupes -s %{buildroot}%{_prefix}
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING CREDITS ChangeLog NEWS README
%{_bindir}/%{name}
%attr(0755,root,games) %{_libexecdir}/%{name}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor
%{_libexecdir}/%{name}

%changelog
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sun Jun 21 2015 nemysis@gmx.ch
- Fix Usage, Unable to load data
- Add twind.sh, that game works from home
- Change Desktop entry file
- Add description for patch
- Use for patch twind-1.1.0 instead of twind-%%{version}
- Add BuildRequires for hicolor-icon-theme
- Change Description
- Change sed, use %%{_libexecdir}/%%{name} instead of share/twind
- Simplify installation handling, use normal build
- Fix build with gcc5, add -fgnu89-inline
* Mon Dec  8 2014 nemysis@gmx.ch
- Use CFLAGS="%%{optflags}" to fix
  'File is compiled without RPM_OPT_FLAGS'
- Install icon in %%{_datadir}/icons/hicolor/-x-/apps/
  instead of %%{_datadir}/pixmaps/
* Fri Nov 14 2014 nemysis@gmx.ch
- Change Source0 to use Web URL
- Use for patch %%{name}-%%{version} instead of twind-1.1.0
* Tue Oct 21 2014 nemysis@gmx.ch
- Remove twind-rpmlintrc
* Sun Oct 19 2014 nemysis@gmx.ch
- Add Source2 twind-rpmlintrc
* Sun Oct 19 2014 nemysis@gmx.ch
- Remove BuildRequires for desktop-file-utils
* Sun Oct 12 2014 nemysis@gmx.ch
- Use check for openSUSE %%if 0%%{?suse_version}
- Use BuildRequires pkgconfig(SDL_image),pkgconfig(SDL_mixer,
  pkgconfig(sdl) instead of libSDL_image-devel, libSDL_mixer-devel,
  SDL-devel
* Mon Oct  6 2014 nemysis@gmx.ch
- Remove BuildRequires for pkgconfig
* Sun Oct  5 2014 nemysis@gmx.ch
- Change %%fdupes
* Tue Sep 30 2014 nemysis@gmx.ch
- Use %%{name}.desktop instead of Desktop Entry in spec
- Use %%{name}-rpmlintrc instead of Patch1
- Remove not needed mkdir -p
* Sat Sep 27 2014 nemysis@gmx.ch
- Use pkgconfig instead of pkgconfig(sdl)
- Change sed, cosmetical changes
* Mon Sep 22 2014 nemysis@gmx.ch
- Correct Path, Highscore and Permissions, that more users can
  use same Highscore with own Results
* Tue Sep 16 2014 nemysis@gmx.ch
- Use $CURRENT_YEAR
- Remove chmod g-s and use %%attr(0755,root,games) %%{_bindir}/%%{name}
- Use %%{_datadir}/%%{name} instead of %%{_datadir}/%%{name}/*
* Fri Sep 12 2014 nemysis@gmx.ch
- Add descriptions for patches
- Reordering BuildRequires, added pkgconfig(sdl)
- Add sed, /usr/bin/twind: Operation not permitted
- Simplify installation handling
- Add localstatedir
* Mon Sep  8 2014 nemysis@gmx.ch
- Fix Desktop file and rpmlint only say
  no-manual-page-for-binary twind which not exist
* Mon Sep  8 2014 nemysis@gmx.ch
- Add twind-1.1.0.twind.c.patch in spec
* Mon Sep  8 2014 nemysis@gmx.ch
- Add forgotten twind-1.1.0.COPYING.patch to twind.spec
* Mon Sep  8 2014 nemysis@gmx.ch
- Initial package creation
- Use mine first FreeBSD port games/twind for patch, new created with Quilt
  twind-1.1.0.twind.c.patch
- Add twind-1.1.0.COPYING.patch, correct Address
- Add Desktop file and icon
- Use %%%%fdupes macro to reduce size of the package
